---
layout: page
title: Frequently Asked Questions
subtitle: If you have a question that isn't answered here, contact us via any of the channels at the bottom of this page  
---

#### How do collective action campaigns work?
1. **Propose**. Anyone can propose a collective action campaign that takes the form *"We will all do X (the 'action') when Y people have pledged (the 'threshold')"*. Campaigns are developed using the issues feature in our [Github repository](https://github.com/freeourknowledge/website/issues) -- just add comments or reactions to any proposals that interest you, or create a new campaign by clicking 'new issue' and filling in the campaign proposal template. 
2. **Crowd**. Once the campaign has been developed we'll post it on the website and open it up to pledges from any researcher around the world. Because pledges remain anonymous and inactive until the critical mass of support is met (unless otherwise directed), researchers can pledge without fear of immediate retribution or harm to their career. 
3. **Act**. If and when the threshold of pledges is met, we'll post the names of all those who have pledged on the website and direct everyone to carry out the pledge in unison, from that day forward. Pledgees can of course act on their pledge early, if they're keen to get started before the threshold is met. 
4. **Evaluate**. Finally, we'll evaluate the success rate of pledges and display completed/broken pledges on the website, both to motivate pledgees to follow through on their pledge and demonstrate the commitment of our community to action. In the future, this data will help us design bigger and bolder campaigns with the maximum chance of impact. 

#### Why focus on simple actions (e.g., preregistration) and small thresholds (e.g., 100 pledges)? 
On a practical note, we're still developing our processes, and starting small with simple actions like this gives us the best chance of reaching the threshold, rolling out the pledge activation phase, and assessing impacts once the campaign has run its course. On a more strategic note, our goal is to build a large community of researchers who act together to solve systemic problems in academia through collective action. Building this community will not happen instantaneously, and will likely require evidence that our community is committed to action. By starting small and collecting pledges across multiple campaigns at once, we give people the opportunity to demonstrate commitment to their pledges, which can then bolster confidence in our community and attract other people to the movement. In time, with data to show that our community follows through on their pledges, we plan to host ever-larger and bolder campaigns that push for widespread systemic change throughout academia. From little things, big things grow. 

#### Why do I need 100 (or X) of my peers to sign before I act? 
You don't! If you'd like to get started early, by all means do. But even if you're planning to carry out the action anyway, joining the campaign will help to (a) signal your commitment to open science practices, (b) increase accountability (as we'll be assessing compliance with the pledges down the track), (c) motivate others to join, and (d) help us reach the critical threshold, which will generate publicity and help grow our community of change-makers. Finally, if/when your pledge activates and you follow through with your pledge, you'll be demonstrating that you are committed to following through on pledges, which will be invaluable in convincing others that we are committed to widespread cultural change. 

#### What happens if my circumstances change before my pledge activates? 
Academia is a turbulent industry, in these difficult times more than ever. We're not interested in punishing you for circumstances beyond your control, so if your situation changes before your pledge activates, just let us know and we'll remove your pledge. Just make sure to do this *prior* to your pledge activating, so that your pledge doesn't trigger other people's pledges before they have the level of community support they were expecting, or detract from our goal of demonstrating a commitment to action within our community.

#### How do I know that people will follow through on their pledges?
We plan to analyse and report when people have followed through on their pledges (e.g., using different colours to indicate completed/broken pledges). In the short term, this approach will provide accountability and motivation for people to uphold their pledges. Moreover, we plan to run a wide range of campaigns, across multiple sectors in academia, which will provide an increasing level of data about who upholds their pledges and under what circumstances. In the long term, we expect that this data will help us tailor campaigns with the highest chance of impact in the community and -- ultimately -- bolster confidence in our community's commitment to action.

#### Are there other pledge sites?
Yes, here are the other pledges we know of (though none of these include a 'critical mass' component):
* [Cost of Knowledge](http://thecostofknowledge.com/)
* [Peer Reviewers' Openness Initiative](https://opennessinitiative.org/)
* [Fraser Lab Lab Compact and Philosophy](https://fraserlab.com/compact/)
* [Open Access Pledge](https://www.openaccesspledge.com)
* [No Free View? No Review!](https://nofreeviewnoreview.org/)
* [Research Without Walls](http://www.researchwithoutwalls.org/)
* [Pledge for sustainable research in theoretical computer science](https://tcs4f.org/)
* [Open Source for Neuroscience](http://opensourceforneuroscience.org/)
* [More Open Access Pledge](https://globalyoungacademy.net/news-release-gya-members-pledge-for-open-access/)

Some researchers have also made individual pledges:
* [Erin McKiernan](https://emckiernan.wordpress.com/pledge/)
* [Daniel Mietchen](https://github.com/Daniel-Mietchen/pledges)
* [Ruben Arslan](https://rubenarslan.github.io/bug_bounty.html)
* [Suchith Anand](https://opensourcegeospatial.icaci.org/2017/07/the-pledge-i-support-open-principles-for-science-and-education-for-building-a-better-world-for-everyone/)
* [Suzan Köseoğlu](https://differentreadings.com/2015/12/01/an-open-pledge/)
* [Jan Ainali](https://github.com/Ainali/pledges)

Many researchers have also signed declarations (supporting a position statement but not committing to specific actions)
* [DORA](https://sfdora.org/signers/) 
* [Budapest Open Access Initiative](https://www.budapestopenaccessinitiative.org/list_signatures) 
* [Berlin call to action for open science](https://en.wikiversity.org/wiki/Wikimedia_Deutschland/Open_Science_Fellows_Program/Berlin_Call_to_Action)
* [Commitment Statement in the Earth, Space, and Environmental Sciences for depositing and sharing data](http://www.copdess.org/enabling-fair-data-project/commitment-to-enabling-fair-data-in-the-earth-space-and-environmental-sciences/)
* [Position Statement on Economic Growth](https://steadystate.org/act/sign-the-position/endorsements-and-signatures/view-all-individual-signatures/)
* [A pledge for planetary health to unite health professionals in the Anthropocene](https://doi.org/10.1016/S0140-6736(20)32039-0)
* [Fair Open Access supporters](https://gitlab.com/publishing-reform/discussion/blob/master/Fair%20Open%20Access/List%20of%20supporters%20of%20Fair%20Open%20Access.md)
* [No-fee science](https://docs.google.com/forms/d/e/1FAIpQLSeGl9IgTZcVDcyinQbosTKhrZVTTVhQ8fUg5Yc9K860AHeDpw/viewform)
* [Freeing sciences](https://journauxscientifiqueslibres.wesign.it/en)
* [Right to share publications](https://www.change.org/p/american-psychological-association-right-to-share-publications?recruiter=11934790&utm_source=share_petition&utm_medium=copylink&utm_campaign=share_petition&utm_term=Search%3ESAP%3EUS%3ENonBrand%3EExact&use_react=false)
